" Vim syntax file
" vim:ts=4:sw=4:expandtab

" put this into to you ~/.vimrc
"
"    augroup syntax
"    au! BufNewFile,BufReadPost *.vam
"    au  BufNewFile,BufReadPost *.vam  so ~/.vim/vam.vim
"    augroup END
"
" ... and save this file as ~/.vim/vam.vim

" Remove any old syntax stuff hanging around
syn clear

" Keywords
syn keyword vamKeyword meta
syn keyword vamKeyword model
syn keyword vamKeyword "pipeline-stages"
syn keyword vamKeyword sig
syn keyword vamKeyword reg
syn keyword vamKeyword mem
syn keyword vamKeyword fnodes
syn keyword vamKeyword connections
syn keyword vamKeyword ports
syn keyword vamKeyword port
syn keyword vamKeyword fnode
syn keyword vamKeyword input
syn keyword vamKeyword assign
syn keyword vamKeyword vt
syn keyword vamKeyword dir
syn keyword vamKeyword inputs
syn keyword vamKeyword output
syn keyword vamKeyword stage
syn keyword vamKeyword timing

" Types
syn keyword vamType we
syn keyword vamType d
syn keyword vamType q
syn keyword vamType stall
syn keyword vamType clr
syn keyword vamType rst
syn keyword vamType en
syn keyword vamType addr
syn keyword vamType address
syn keyword vamType enable
syn keyword vamType control
syn keyword vamType unknown
syn keyword vamType data
syn keyword vamType ro
syn keyword vamType wo
syn keyword vamType rw

" Operators
syn keyword vamOperator switch
syn keyword vamOperator cond
syn keyword vamOperator default
syn keyword vamOperator         "_"
syn keyword vamOperator         "!"
syn keyword vamOperator         "?"
syn keyword vamOperator         "~"
syn keyword vamOperator         "|"
syn keyword vamOperator         "&"
syn keyword vamOperator         "^"
syn keyword vamOperator         "<"
syn keyword vamOperator         ">"
syn keyword vamOperator         "."
syn keyword vamOperator         "+"
syn keyword vamOperator         "-"
syn keyword vamOperator         "*"
syn keyword vamOperator         "/"
syn keyword vamOperator         ":="
syn keyword vamOperator         "||"
syn keyword vamOperator         "&&"
syn keyword vamOperator         "<<"
syn keyword vamOperator         ">>"
syn keyword vamOperator         "=="
syn keyword vamOperator         "!="
syn keyword vamOperator         "<="
syn keyword vamOperator         ">="
syn keyword vamOperator         "<."
syn keyword vamOperator         ">."
syn keyword vamOperator         "-."
syn keyword vamOperator         ".-"
syn keyword vamOperator         "[]"
syn keyword vamOperator         "^^"
syn keyword vamOperator         "--"
syn keyword vamOperator         "!!"
syn keyword vamOperator         "~~"
syn keyword vamOperator         "<>"
syn keyword vamOperator         "]["
syn keyword vamOperator         "-+"
syn keyword vamOperator         ">>."
syn keyword vamOperator         "<=."
syn keyword vamOperator         ">=."
syn keyword vamOperator         "^^."
syn keyword vamOperator         "[..]"


" Preprocessor
syn match   vamPreproc          "#.*"
" Constants
syn match   vamNumber           "-\=\<[0-9]\+"

syn match   vamSpecialError		contained "\\."
syn match   vamSpecialCharError	contained "[^']"
syn match   vamSpecialChar		contained +\\["\\'0abfnrtvx]+
syn region  vamString			start=+"+  end=+"+ end=+$+ contains=vamSpecialChar,vamSpecialError,@Spell

"Comment
syn match   vamComment          ";;.*"
syn match   vamComment          "//.*"
syn region  vamComment          start="/\*" end="\*/"
syn keyword vamTodo FIXME
syn keyword vamTodo TODO

" Catch mismatched parentheses
syn region vamParen             transparent start="(" end=")" contains=ALLBUT,vamParenError
syn match vamParenError         ")"

syn sync lines=10

if !exists("did_vam_syntax_inits")
    let did_vam_syntax_inits = 1
    " The default methods for highlighting.  Can be overridden later
    hi link vamKeyword        Statement
    hi link vamNumber         Number
    hi link vamString         String
    hi link vamOperator       Special
    hi link vamPreproc        Special
    hi link vamComment        Comment
    hi link vamType           Type
    hi link vamTempOperator   Type
    hi link vamParenError     Error
    hi link vamBracketError   Error
    hi link vamTodo           Todo
endif

let b:current_syntax = "vam"
